Module: Newman
- Defined in:
- lib/newman/store.rb,
lib/newman/mailer.rb,
lib/newman/server.rb,
lib/newman/filters.rb,
lib/newman/version.rb,
lib/newman/recorder.rb,
lib/newman/settings.rb,
lib/newman/controller.rb,
lib/newman/application.rb,
lib/newman/test_mailer.rb,
lib/newman/email_logger.rb,
lib/newman/mailing_list.rb,
lib/newman/request_logger.rb,
lib/newman/response_logger.rb
Overview
Newman::ResponseLogger supports rudimentary response logging functionality, which is
enabled by default when Newman::Server.simple is used to execute your
applications.
If you are only interested in making use of this logging functionality and not
extending it or changing it in some way, you do not need to be familiar with
the code in this file. Just be sure to note that if you add
service.debug_mode = true to your configuration file, or set the Ruby
$DEBUG global variable, you will get much more verbose output from
Newman's logging system.
Newman::ResponseLogger is part of Newman's internal interface.
Defined Under Namespace
Modules: EmailLogger, Filters, Version Classes: Application, Controller, Mailer, MailingList, Record, Recorder, Server, Settings, Store, TestMailer
Constant Summary collapse
- RequestLogger =
Object.new
- ResponseLogger =
Object.new